@@ -1,16 +1,15 @@
-import glob
-from typing import List, Any, Iterable
+import json
+from glob import iglob
+from typing import List, Any, Callable
 
 import requests
 from datahub.emitter.mcp import MetadataChangeProposalWrapper, DictWrapper
 from datahub.metadata.schema_classes import ChangeTypeClass
-from glob import iglob
-import json
 
 from dh_client.client import RestClient
 from dh_client.exceptions import NotSupportedYet
 
-__all__ = ["datasets", "glossary_terms", "owners", "tags", "users"]
+__all__ = ["datasets", "glossary_terms", "owners", "tags", "users", "dashboards"]
 
 
 class Entity:
@@ -47,21 +46,37 @@ class Entity:
                     MetadataChangeProposalWrapper(changeType=change_type, **mpc_)
                 )
 
-    def _create_mpc_from_file(self, file_pattern: str) -> List[dict]:
-        """Create list of mpc based on the given file pattern."""
+    def _create_mpc_from_file(
+        self, file_pattern: str, filter_func: Callable = None, recursive: bool = False
+    ) -> List[dict]:
+        """Create list of mpc based on the given file pattern.
+
+        Args:
+            file_pattern: The file-pattern (feel free to use wildcards).
+            filter_func: an extra function to filter files.
+            recursive: Match files recursively or not.
+
+        Return: The list of MPC dictionaries.
+        """
         mpc = []
-        for filepath in iglob(file_pattern):
+        files_iter = (
+            filter(filter_func, iglob(file_pattern, recursive=recursive))
+            if filter_func
+            else iglob(file_pattern, recursive=recursive)
+        )
+        for filepath in files_iter:
             with open(filepath, "r") as f:
                 j = json.load(f)
                 if isinstance(j, dict):
                     j = [j]
                 for item in j:
-                    mpc.extend(self._create_mpc(**item))
+                    if item:
+                        mpc.extend(self._create_mpc(**item))
         return mpc
 
-    def _create_mpc(self, **kwargs):
+    def _create_mpc(self, **kwargs) -> List[dict]:
         """This method is implemented by the subclasses."""
-        raise NotImplementedError
+        return [kwargs]
 
     @staticmethod
     def _create_mpc_dict(
